@@ -12,4 +12,4 @@ manage_cache <- NULL # nocov start
       x$cache_path_set(path = "getCRUCLdata", type = "user_cache_dir")
       manage_cache <<- x
     }
-  }
+  } # nocov end
